@@ -6,10 +6,11 @@ use English qw[-no_match_vars];
 use Moo;
 use App::BoolFindGrep;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 has args   => ( is => q(rw), default => sub { {}; }, );
 has result => ( is => q(rw), default => sub { []; }, );
+has files_with_matches => ( is => q(rw) );
 
 sub process {
     my $self = shift;
@@ -47,13 +48,17 @@ sub process {
                     = $controller->grep->content_found->{$file}{$number};
             }
         }
-        foreach my $file (%result) {
+        foreach my $file ( sort keys %result ) {
+            if ( $self->files_with_matches() ) {
+                push @{ $self->result() }, $file;
+                next;
+            }
             foreach my $number ( sort { $a <=> $b } keys %{ $result{$file} } )
             {
                 my $string = $result{$file}{$number};
                 my $result = sprintf q(%s:%.*d:%s),     #
                     $file, length $num_max, $number, $string;
-                push @{$self->result()}, $result;
+                push @{ $self->result() }, $result;
             }
         }
 
@@ -81,12 +86,13 @@ sub args_checker {
         q(an empty value was given.) =>
             [qw[file_delim file_expr files_from match_expr directory]],
         q(implies) => [
-            { find_type        => [q(file_expr)] },
-            { find_ignore_case => [q(file_expr)] },
-            { files_delim      => [q(files_from)] },
-            { ignore_case      => [q(match_expr)] },
-            { line_regexp      => [q(match_expr)] },
-            { word_regexp      => [q(match_expr)] },
+            { find_type          => [q(file_expr)] },
+            { find_ignore_case   => [q(file_expr)] },
+            { files_delim        => [q(files_from)] },
+            { ignore_case        => [q(match_expr)] },
+            { line_regexp        => [q(match_expr)] },
+            { word_regexp        => [q(match_expr)] },
+            { files_with_matches => [q(match_expr)] },
         ],
     );
 
@@ -108,7 +114,10 @@ sub args_checker {
     foreach my $parameter ( keys %{ $self->args() } ) {
         my $value = $self->args->{$parameter};
         my $checker = sprintf q(_%s_checker), $parameter;
-        if ( $self->can($checker) ) {
+        if ( $parameter eq q(files_with_matches) ) {
+            $self->$parameter( delete $self->args->{$parameter} );
+        }
+        elsif ( $self->can($checker) ) {
             return unless $self->$checker($value);
         }
     }
@@ -310,7 +319,7 @@ App::BoolFindGrep::CLI - Command Line Interface functions.
 
 =head1 VERSION
 
-version 0.04
+version 0.06
 
 =head1 SYNOPSIS
 
